OC.L10N.register(
    "circles",
    {
    "Circles" : "Кръгове",
    "Circles' files" : "Файлове на кръгове",
    "Select circles to filter by" : "Изберете кръгове, по които да филтрирате",
    "No circles found" : "Няма намерени кръгове",
    "Please select circles to filter by" : "Моля, изберете кръгове по които да филтрирате",
    "No files found for the selected circles" : "Няма намерени файлове за избраните кръгове",
    "You created the circle {circle}" : "Вие създадохте кръгът {circle}",
    "{author} created the circle {circle}" : "{author} създаде кръгът {circle}",
    "You deleted {circle}" : "Вие изтрихте {circle}",
    "{author} deleted {circle}" : "{author} изтри {circle}",
    "You linked {group} to {circle}" : "Вие свързахте {group} към {circle}",
    "{group} has been linked to {circle} by {author}" : "{group} бе свързана с {circle} от {author}",
    "You unlinked {group} from {circle}" : "Вие прекъснахте връзката на {group} с {circle}",
    "{group} has been unlinked from {circle} by {author}" : "На {group} е прекратена връзката с {circle} от {author}",
    "You changed the level of the linked group {group} in {circle} to %1$s" : "Вие променихте нивото на свързаната група {group} в {circle} на %1$s",
    "{author} changed the level of the linked group {group} in {circle} to %1$s" : "{author} промени нивото на свързаната група {group} в {кръг} на %1$s",
    "You sent a request to link {circle} with {remote}" : "Изпратихте заявка за свързване на {circle} с {remote}",
    "{author} sent a request to link {circle} with {remote}" : "{author} изпрати заявка за свързване на {circle} с {remote}",
    "{remote} requested a link with {circle}" : "{remote} поиска заявка за връзка с {circle}",
    "The request to link {circle} with {remote} has been rejected" : "Искането за свързване на {circle} с {remote} беше отхвърлено",
    "The request to link {remote} with {circle} has been canceled remotely" : "Искането за свързване на {remote} с {circle} беше отменено от разстояние",
    "The request to link {circle} with {remote} has been accepted" : "Заявката за свързване на {circle} с {remote} беше приета",
    "You dismissed the request to link {remote} with {circle}" : "Отхвърлихте заявката за свързване на {remote} с {circle}",
    "{author} dismissed the request to link {remote} with {circle}" : "{author} отхвърли заявката за свързване на {remote} с {circle}",
    "You canceled the request to link {circle} with {remote}" : "Отменихте заявката за свързване на {circle} с {remote}",
    "{author} canceled the request to link {circle} with {remote}" : "{author} отмени заявката за свързване на {circle} с {remote}",
    "You accepted the request to link {remote} with {circle}" : "Приехте заявката за свързване на {remote} с {circle}",
    "{author} accepted the request to link {remote} with {circle}" : "{author} прие заявката за свързване на {remote} с {circle}",
    "A link between {circle} and {remote} is now up and running" : "Връзката между {circle} и {remote} вече е създадена и работи",
    "The link between {circle} and {remote} has been shutdown remotely" : "Връзката между {circle} и {remote} беше изключена от разстояние",
    "You closed the link between {circle} and {remote}" : "Затворихте връзката между {circle} и {remote}",
    "{author} closed the link between {circle} and {remote}" : "{author} затвори връзката между {circle} и {remote}",
    "You joined {circle}" : "Вие се присъединихте към {circle}",
    "{member} joined {circle}" : "{member} се присъедини към {circle}",
    "You accepted the invitation to join {circle}" : "Приехте поканата да се присъедините към {circle}",
    "{member} accepted the invitation to join {circle}" : "{member} прие поканата да се присъедини към {circle}",
    "You added {member} as member to {circle}" : "Вие добавихте {member} като член на {circle}",
    "You have been added as member to {circle} by {author}" : "Бяхте добавен като член в {circle} от {author}",
    "{member} has been added as member to {circle} by {author}" : "{member} беше добавен като член в {circle} от {author}",
    "You added {external} to {circle}" : " Добавихте {external} към {circle}",
    "{external} has been added to {circle} by {author}" : "{external} беше добавен към {circle} от {author}",
    "You accepted {member}'s request to join {circle}" : "Приехте молбата на {member} да се присъедини към {circle}",
    "Your request to join {circle} has been accepted by {author}" : "Заявката ви за присъединяване към {circle} беше приета от {author}",
    "{member}'s request to join {circle} has been accepted by {author}" : "Заявката на {member} да се присъедини към {circle} беше приета от {author}",
    "You left {circle}" : "Вие напуснахте {circle}",
    "{member} left {circle}" : "{member} напусна {circle}",
    "You declined the invitation to join {circle}" : "Отказахте поканата да се присъедините към {circle}",
    "{member} declined an invitation to join {circle}" : "{member} отказа поканата да се присъедини към  {circle}",
    "You cancelled your request to join {circle}" : "Отменихте заявката си за присъединяване към {circle}",
    "{member} cancelled his request to join {circle}" : "{member} отмени заявката си за присъединяване към {circle}",
    "You removed {member} from {circle}" : "Премахнахте {member} от {circle}",
    "You have been removed from {circle} by {author}" : "Бяхте премахнат от {circle} от {author}",
    "{member} has been removed from {circle} by {author}" : "{member} беше премахнат от {circle} от {author}",
    "You removed {external} from {circle}" : "Вие премахнахте {external} от {circle}",
    "{external} has been removed from {circle} by {author}" : "{external} беше премахнат от {circle} от {author}",
    "You cancelled {member}'s invitation to join {circle}" : "Отменихте поканата на {member} да се присъедини към {circle}",
    "Your invitation to join {circle} has been cancelled by {author}" : "Вашата покана за присъединяване към {circle} беше отменена от {author}",
    "{author} cancelled {member}'s invitation to join {circle}" : "{author} отмени поканата на {member} да се присъедини към {circle}",
    "You dismissed {member}'s request to join {circle}" : "Отхвърлихте молбата на {member} за присъединяване към {circle}",
    "Your request to join {circle} has been dismissed by {author}" : "Заявката ви за присъединяване към {circle} беше отхвърлена от {author}",
    "{member}'s request to join {circle} has been dismissed by {author}" : "Заявката на {member} да се присъедини към {кръг} беше отхвърлена от {author}",
    "You invited {member} to join {circle}" : "Поканихте {member} да се присъедини към {circle}",
    "You have been invited to join {circle} by {author}" : " Бяхте поканен да се присъедините към {circle} от {author}",
    "{member} has been invited to join {circle} by {author}" : "{member} беше поканен да се присъедини към {circle} от {author}",
    "You changed {member}'s level in {circle} to %1$s" : "Променихте нивото на {member} в {circle} на %1$s",
    "{author} changed your level in {circle} to %1$s" : "{author} промени вашето ниво в {circle} на %1$s",
    "{author} changed {member}'s level in {circle} to %1$s" : "{author} промени нивото на {member} в {circle} на %1$s ",
    "You sent a request to join {circle}" : "Изпратили сте заявка за присъединяване към {circle}",
    "{member} sent a request to join {circle}" : "{member} изпрати заявка за присъединяване към {circle}",
    "You are the new owner of {circle}" : "Вие сте новият собственик на {circle}",
    "{member} is the new owner of {circle}" : "{member} е новият собственик на {circle}",
    "On events happening in a <strong>Circle</strong> of which you are a member" : "На събития, случващи се в <strong>Circle</strong>, в който вие сте член",
    "Any important event in a <strong>Circle</strong> you are moderating" : "Всяко важно събитие в <strong>Circle</strong>, което вие модерирате",
    "On global events happening in any <strong>Circle</strong>" : "На глобални събития, които се случват във всеки <strong>Circle</strong>",
    "Single" : "Единичен",
    "Personal" : "Лични",
    "System" : "Система",
    "Visible" : "Видимо",
    "Open" : "Отвори",
    "Invite" : "Покани",
    "Join Request" : "Заявка за присъединяване",
    "Friends" : "Приятели",
    "Password Protected" : "Защитено с парола",
    "No Owner" : "Няма собственик",
    "Hidden" : "Скрит",
    "Backend" : " Сървър",
    "Local" : "Локален",
    "Root" : "Основен",
    "Circle Invite" : "Покана за Circle/кръг/",
    "Federated" : "Федериран",
    "Mount point" : "Точка на монтиране",
    "Nextcloud Account" : "Nextcloud профил",
    "Nextcloud Group" : "Nextcloud Група",
    "Email Address" : "Имейл адрес",
    "Contact" : "Контакт",
    "Circle" : "Кръг",
    "Nextcloud App" : "Приложение Nextcloud App",
    "Member" : "Член",
    "Moderator" : "Модератор",
    "Admin" : "Администратор",
    "Owner" : "Създател",
    "%s shared »%s« with you." : "%s сподели »%s« с вас.",
    "%s shared »%s« with \"%s\"." : "%s сподели »%s« с „%s“.",
    "%s on %s" : "%s на %s",
    "%1$s shared »%2$s« with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$sсподели »%2$s« с вас. Вече трябва да сте получили отделен имейл с връзка за достъп до него.\n",
    "%1$s shared »%2$s« with you. You should have already received a separate email with a link to access it." : "%1$s сподели %2$s с вас. Вече трябва да сте получили отделен имейл с връзка за достъп до него.",
    "Password to access »%1$s« shared to you by %2$s" : "Парола за достъп »%1$s» е споделенас вас от %2$s",
    "Password to access »%s«" : "Парола за достъп »%s»",
    "It is protected with the following password:" : "Защитен е със следната парола:",
    "%1$s via %2$s" : "%1$sчрез %2$s ",
    "Click the button below to open it." : "Щракнете върху бутона по-долу, за да го отворите.",
    "Open »%s«" : "Отвори »%s«",
    "%1$s shared multiple files with you.\nYou should have already received a separate email with a link to access them.\n" : "%1$s сподели множество файла с вас. Вече трябва да сте получили отделен имейл с връзка за достъп до тях.\n",
    "%1$s shared multiple files with you. You should have already received a separate email with a link to access them." : "%1$sсподели множество файлове с вас. Вече трябва да сте получили отделна поща с връзка за достъп до тях. ",
    "Password to access files shared to you by %1$s" : "Парола за достъп до файлове, споделени с вас от %1$s",
    "Password to access files" : "Парола за достъп до файлове",
    "%s shared multiple files with \"%s\"." : "%s сподели множество файла с „%s“.",
    "%s shared multiple files with you." : "%sсподелени множество файлове с вас",
    "Boot up" : "Стартиране",
    "Initialisation Nextcloud" : "Nextcloud Инициализация",
    "Initialisation Circles App" : "Инициализация на Приложението Circles",
    "Fresh installation status" : "Състояние на нова инсталация",
    "Building Local Database" : "Изграждане на Локална База Данни",
    "Testing Basic Circle Creation" : "Тестване на създаването на основен кръг",
    "Adding local users and moderators" : "Добавяне на локални потребители и модератори",
    "Circle not found" : "Кръгът не е намерен",
    "Circle not found " : "Кръгът не е намерен",
    "A circle with that name exists" : "Съществува кръг с това име",
    "You cannot use the Circles Application until your administrator has allowed at least one type of circles" : "Не можете да използвате Приложението Кръгове, докато вашият администратор не е разрешил поне един тип от кръгове",
    "This member does not exist" : "Този член не съществува",
    "This account is already a member of the circle" : "Този профил вече е член на кръга",
    "Federated link not found" : "Федерираната връзка не е намерена",
    "This feature is not available for personal circles" : "Тази функция не е налична за лични кръгове",
    "The circle is not federated" : "Кръгът не е федериран",
    "You cannot join this circle" : "Не можете да се присъедините към този кръг",
    "This member is not a moderator" : "Този член не е модератор",
    "Insufficient privileges" : "Недостатъчни привилегии",
    "This member is the owner of the circle" : "Този член е собственикът на кръга",
    "Level cannot be changed for this type of member" : "Нивото не може да се променя за член от този тип ",
    "You are already a member of this circle" : "Вече сте член на този кръг",
    "You have been blocked from this circle" : "Бяхте блокиран от този кръг",
    "The account is already a member of this circle" : "Този профил вече е член на този кръг",
    "The account has already been invited into this circle" : "Този профил вече е бил поканен в този кръг",
    "%s (Circle owned by %s)" : "%s (Кръг, притежаван от %s)",
    "You are now a member of the Circle \"%2$s\"" : " \nВече сте член на Кръга \"%2$s\"",
    "You have been invited by %1$s into the Circle \"%2$s\"" : "Вие сте поканени от %1$s в Кръга \"%2$s\"",
    "%1$s sent a request to be a member of the Circle \"%2$s\"" : "%1$s са изпратили заявка да бъдат членове на Кръга \"%2$s\"",
    "Accept" : "Приемане",
    "Refuse" : "Отказ",
    "Leave the circle" : "Напускане на кръга",
    "%s" : "%s",
    "Personal Circle" : "Личен кръг",
    "%s owned by %s" : "%s притежаван от  %s",
    "You need a specify a type of circle" : "Трябва да посочите тип кръг",
    "This member is not the owner of the circle" : "Този член не е собственик на кръга",
    "This member is not an admin of the circle" : "Този член не е администратор на кръга",
    "Group contains too many members" : "Групата съдържа твърде много членове",
    "This group does not exist" : "Тази група не съществува",
    "This group is already linked to the circle" : "Тази група вече е свързана с кръга",
    "You cannot edit level in a personal circle" : "Не можете да редактирате ниво в личен кръг",
    "Group cannot be set as owner of a circle" : "Група не може да бъде зададена като собственик на кръг",
    "now" : "сега",
    "This account does not exist" : "Този профил не съществува",
    "Email format is not valid" : "Невалиден Имейл формат",
    "This contact is not available" : "Този контакт е недостъпен",
    "You have no permission to create a new circle" : "Нямате право да създавате нов кръг /circle/",
    "%s shared a file with \"%s\"." : "%s сподели файл с „%s“.",
    "%s shared a file with you." : "%sсподели файл с вас. ",
    "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s сподели някакво съдържание с вас.\nВече трябва да сте получили отделен имейл с връзка за достъп до него.\n",
    "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "%1$s сподели някакво съдържание с вас.\nВече трябва да сте получили отделен имейл с връзка за достъп до него.",
    "Password to access content shared with you by %1$s" : "Парола за достъп до съдържание, споделени с вас от %1$s",
    "Password to access content" : "Парола за достъп до съдържание",
    "This item is already shared with this circle" : "Елементът вече е споделен с този кръг",
    "Could not find share" : "Споделянето не можа да се намери",
    "Bring cloud-users closer together." : "Доближете потребителите на облака по-близо.",
    "Circles allows people to create their own groups of people/colleagues/friends.\nThose groups of people (or \"circles\") can then be used by any other app for sharing purpose." : "Приложението Circles /Кръгове/, позволява на хората да създават свои собствени групи от хора/колеги/приятели.\nТези групи от хора (или \"кръгове\") след това могат да се използват от всяко друго приложение за споделяне.",
    "No files in here" : "Няма файлове",
    "No entries found in this folder" : "Папката е празна",
    "Name" : "Име",
    "Size" : "Размер",
    "Modified" : "Променен на",
    "Nextcloud User" : "Потребител на Nextcloud",
    "This user is already a member of the circle" : "Този потребител вече е член на кръга",
    "The user is already a member of this circle" : "Потребителят вече е член на този кръг",
    "The user has already been invited into this circle" : "Потребителят вече е поканен в този кръг",
    "This user does not exist" : "Този потребител не съществува",
    "Circles allows your users to create their own groups of users/colleagues/friends.\nThose groups of users (or \"circles\") can then be used by any other app for sharing purpose." : "Circles позволява на вашите потребители да създават свои собствени групи потребители/колеги/приятели.\nТези групи потребители (или „кръгове“) след това могат да бъдат използвани от всяко друго приложение за споделяне."
},
"nplurals=2; plural=(n != 1);");
